pub fn unzip(zip: impl Read + Seek, target: &Path) -> Result<(), TmcError>
Finds a project directory in the given zip and unzips it according to the given student policy. Also cleans unnecessary non-student files.